@@ -1,11 +1,11 @@
 plot_joignantes <-
-function(data,fondMaille,fondSousAnalyse=NULL,fondSurAnalyse=NULL,typeMaille,idDataDepart,idDataArrivee,varFlux,largeurFlecheMax=NULL,filtreVol=0,filtreDist=100,filtreMajeurs=10,decalageAllerRetour=0,decalageCentroid=0,emprise="FRM",precisionLegFleches=0,titreLeg="",xLeg=NULL,yLeg=NULL,titreCarte="",sourceCarte="",etiquettes=NULL,colFleche="#CD853F",colBorder="white",colBorderMaille="black",xlim=NULL,ylim=NULL)
+function(data,fondMaille,fondSousAnalyse=NULL,fondSurAnalyse=NULL,typeMaille,idDataDepart,idDataArrivee,varFlux,largeurFlecheMax=NULL,filtreVol=0,filtreDist=100,filtreMajeurs=10,decalageAllerRetour=0,decalageCentroid=0,emprise="FRM",precisionLegFleches=0,titreLeg="",xLeg=NULL,yLeg=NULL,cadreLeg=FALSE,xLimCadreLeg=NULL,yLimCadreLeg=NULL,titreCarte="",sourceCarte="",etiquettes=NULL,colFleche="#CD853F",colBorder="white",colBorderMaille="black",xlim=NULL,ylim=NULL)
   {
     options("stringsAsFactors"=FALSE)
 
     # Verification des parametres
 
-    msg_error1<-msg_error2<-msg_error3<-msg_error4<-msg_error5<-msg_error6<-msg_error7<-msg_error8<-msg_error9<-msg_error10<-msg_error11<-msg_error12<-msg_error13<-msg_error14<-msg_error15<-msg_error16<-msg_error17<-msg_error18<-msg_error19<-msg_error20<-msg_error21<-msg_error22<-msg_error23<-msg_error24<-msg_error25<-msg_error26<-msg_error27<-msg_error28<-msg_error29<-msg_error30<-msg_error31<-msg_error32<-msg_error33<-msg_error34 <- NULL
+    msg_error1<-msg_error2<-msg_error3<-msg_error4<-msg_error5<-msg_error6<-msg_error7<-msg_error8<-msg_error9<-msg_error10<-msg_error11<-msg_error12<-msg_error13<-msg_error14<-msg_error15<-msg_error16<-msg_error17<-msg_error18<-msg_error19<-msg_error20<-msg_error21<-msg_error22<-msg_error23<-msg_error24<-msg_error25<-msg_error26<-msg_error27<-msg_error28<-msg_error29<-msg_error30<-msg_error31<-msg_error32<-msg_error33<-msg_error34<-msg_error35<-msg_error36<-msg_error37 <- NULL
 
     if(any(class(data)!="data.frame")) msg_error1 <- "Les donnees doivent etre dans un data.frame / "
     if(any(!any(class(fondMaille) %in% "sf"),!any(class(fondMaille) %in% "data.frame"))) msg_error2 <- "Le fond de maille doit etre un objet sf / "
@@ -26,23 +26,26 @@ function(data,fondMaille,fondSousAnalyse=NULL,fondSurAnalyse=NULL,typeMaille,idD
     if(any(class(titreLeg)!="character")) msg_error17<- "Le titre de la legende doit etre de type caractere / "
     if(!is.null(xLeg)) if(any(class(xLeg)!="numeric")) msg_error18 <- "La variable xLeg doit etre de type numerique / "
     if(!is.null(yLeg)) if(any(class(yLeg)!="numeric")) msg_error19 <- "La variable yLeg doit etre de type numerique / "
-    if(any(class(titreCarte)!="character")) msg_error20 <- "Le titre de la carte doit etre de type caractere / "
-    if(any(class(sourceCarte)!="character")) msg_error21 <- "La source de la carte doit etre de type caractere / "
-    if(!is.null(etiquettes)) if(!any(class(etiquettes) %in% "character" | class(etiquettes) %in% "data.frame")) msg_error22 <- "La table des etiquettes peut etre soit un vecteur caractere soit un data.frame (voir aide) / "
-    if(!is.null(colFleche)) if(any(class(colFleche)!="character")) msg_error23 <- "La couleur doit etre de type caractere (nommee ou hexadecimal) / "
-    if(any(class(colBorder)!="character")) msg_error24 <- "La couleur de la bordure de fleche doit etre de type caractere (nommee ou hexadecimal) / "
-    if(any(class(colBorderMaille)!="character")) msg_error25 <- "La couleur de la bordure de maille doit etre de type caractere (nommee ou hexadecimal) / "
-    if(!is.null(xlim)) if(any(class(xlim)!="numeric")) msg_error26 <- "La variable xlim doit etre de type numerique / "
-    if(!is.null(ylim)) if(any(class(ylim)!="numeric")) msg_error27 <- "La variable yim doit etre de type numerique / "
+    if(any(class(cadreLeg)!="logical")) msg_error20 <- "La variable cadreLeg doit etre logique TRUE ou FALSE / "
+    if(!is.null(xLimCadreLeg)) if(any(class(xLimCadreLeg)!="numeric")) msg_error21 <- "La variable xLimCadreLeg doit etre de type numerique / "
+    if(!is.null(yLimCadreLeg)) if(any(class(yLimCadreLeg)!="numeric")) msg_error22 <- "La variable yLimCadreLeg doit etre de type numerique / "
+    if(any(class(titreCarte)!="character")) msg_error23 <- "Le titre de la carte doit etre de type caractere / "
+    if(any(class(sourceCarte)!="character")) msg_error24 <- "La source de la carte doit etre de type caractere / "
+    if(!is.null(etiquettes)) if(!any(class(etiquettes) %in% "character" | class(etiquettes) %in% "data.frame")) msg_error25 <- "La table des etiquettes peut etre soit un vecteur caractere soit un data.frame (voir aide) / "
+    if(!is.null(colFleche)) if(any(class(colFleche)!="character")) msg_error26 <- "La couleur doit etre de type caractere (nommee ou hexadecimal) / "
+    if(any(class(colBorder)!="character")) msg_error27 <- "La couleur de la bordure de fleche doit etre de type caractere (nommee ou hexadecimal) / "
+    if(any(class(colBorderMaille)!="character")) msg_error28 <- "La couleur de la bordure de maille doit etre de type caractere (nommee ou hexadecimal) / "
+    if(!is.null(xlim)) if(any(class(xlim)!="numeric")) msg_error29 <- "La variable xlim doit etre de type numerique / "
+    if(!is.null(ylim)) if(any(class(ylim)!="numeric")) msg_error30 <- "La variable yim doit etre de type numerique / "
 
-    if(length(names(data))<3) msg_error28 <- "Le tableau des donnees n'est pas conforme. Il doit contenir au minimum une variable de depart, une variable d'arrivee et la variable a representer / "
-    if(length(names(fondMaille))<3) msg_error29 <- "Le fond de maille n'est pas conforme. La table doit contenir au minimum une variable identifiant, une variable libelle et la geometry / "
+    if(length(names(data))<3) msg_error31 <- "Le tableau des donnees n'est pas conforme. Il doit contenir au minimum une variable de depart, une variable d'arrivee et la variable a representer / "
+    if(length(names(fondMaille))<3) msg_error32 <- "Le fond de maille n'est pas conforme. La table doit contenir au minimum une variable identifiant, une variable libelle et la geometry / "
 
-    if(!typeMaille %in% c("REG", "DEP", "ZE", "AU", "BV", "UU", "EPCI", "DEPCOM")) msg_error30 <- "La variable typeMaille doit etre 'REG', 'DEP', 'ZE', 'AU', 'BV', 'UU', 'EPCI' ou 'DEPCOM' / "
-    if(!any(names(data) %in% idDataDepart))  msg_error31 <- "La variable de depart n'existe pas dans la table des donnees / "
-    if(!any(names(data) %in% idDataArrivee))  msg_error32 <- "La variable d'arrivee n'existe pas dans la table des donnees / "
-    if(!any(names(data) %in% varFlux))  msg_error33 <- "La variable a representer n'existe pas dans la table des donnees / "
-    if(!emprise %in% c("FRM","971","972","973","974","976")) msg_error34 <- "La variable emprise doit etre 'FRM', '971', '972', '973', '974' ou '976' / "
+    if(!typeMaille %in% c("REG", "DEP", "ZE", "AU", "BV", "UU", "EPCI", "DEPCOM")) msg_error33 <- "La variable typeMaille doit etre 'REG', 'DEP', 'ZE', 'AU', 'BV', 'UU', 'EPCI' ou 'DEPCOM' / "
+    if(!any(names(data) %in% idDataDepart))  msg_error34 <- "La variable de depart n'existe pas dans la table des donnees / "
+    if(!any(names(data) %in% idDataArrivee))  msg_error35 <- "La variable d'arrivee n'existe pas dans la table des donnees / "
+    if(!any(names(data) %in% varFlux))  msg_error36 <- "La variable a representer n'existe pas dans la table des donnees / "
+    if(!emprise %in% c("FRM","971","972","973","974","976")) msg_error37 <- "La variable emprise doit etre 'FRM', '971', '972', '973', '974' ou '976' / "
 
     if(any(!is.null(msg_error1),!is.null(msg_error2),!is.null(msg_error3),!is.null(msg_error4),
            !is.null(msg_error5),!is.null(msg_error6),!is.null(msg_error7),!is.null(msg_error8),
@@ -51,12 +54,14 @@ function(data,fondMaille,fondSousAnalyse=NULL,fondSurAnalyse=NULL,typeMaille,idD
            !is.null(msg_error17),!is.null(msg_error18),!is.null(msg_error19),!is.null(msg_error20),
            !is.null(msg_error21),!is.null(msg_error22),!is.null(msg_error23),!is.null(msg_error24),
            !is.null(msg_error25),!is.null(msg_error26),!is.null(msg_error27),!is.null(msg_error28),
-           !is.null(msg_error29),!is.null(msg_error30),!is.null(msg_error31),!is.null(msg_error32),!is.null(msg_error33),!is.null(msg_error34)))
+           !is.null(msg_error29),!is.null(msg_error30),!is.null(msg_error31),!is.null(msg_error32),
+           !is.null(msg_error33),!is.null(msg_error34),!is.null(msg_error35),!is.null(msg_error36),!is.null(msg_error37)))
     {
       stop(simpleError(paste0(msg_error1,msg_error2,msg_error3,msg_error4,msg_error5,msg_error6,msg_error7,msg_error8,
                               msg_error9,msg_error10,msg_error11,msg_error12,msg_error13,msg_error14,msg_error15,
                               msg_error16,msg_error17,msg_error18,msg_error19,msg_error20,msg_error21,msg_error22,
-                              msg_error23,msg_error24,msg_error25,msg_error26,msg_error27,msg_error28,msg_error29,msg_error30,msg_error31,msg_error32,msg_error33,msg_error34)))
+                              msg_error23,msg_error24,msg_error25,msg_error26,msg_error27,msg_error28,msg_error29,msg_error30,
+                              msg_error31,msg_error32,msg_error33,msg_error34,msg_error35,msg_error36,msg_error37)))
     }
 
     names(data)[names(data)==idDataDepart] <- "CODE1"
@@ -200,8 +205,19 @@ function(data,fondMaille,fondSousAnalyse=NULL,fondSurAnalyse=NULL,typeMaille,idD
     xmax <- max(st_coordinates(flux_leg)[,1]) + (x_large*3)
     ymin <- min(st_coordinates(flux_leg)[,2]) - y_large
     ymax <- max(st_coordinates(flux_leg)[,2]) + (y_large*3)
-    bbox_leg_joignantes <- matrix(c(xmin,ymax, xmax,ymax, xmax,ymin, xmin,ymin, xmin,ymax),ncol=2, byrow=TRUE)
-    bbox_leg_joignantes <- st_sf(geometry=st_sfc(st_polygon(list(bbox_leg_joignantes))),crs=st_crs(fondMaille))
+
+    if(cadreLeg)
+    {
+      if(is.null(xLimCadreLeg) | is.null(xLimCadreLeg))
+      {
+        bbox_leg_joignantes <- matrix(c(xmin,ymax, xmax,ymax, xmax,ymin, xmin,ymin, xmin,ymax),ncol=2, byrow=TRUE)
+        bbox_leg_joignantes <- st_sf(geometry=st_sfc(st_polygon(list(bbox_leg_joignantes))),crs=st_crs(fondMaille))
+      }else
+      {
+        bbox_leg_joignantes <- matrix(c(xLimCadreLeg[1],yLimCadreLeg[2], xLimCadreLeg[2],yLimCadreLeg[2], xLimCadreLeg[2],yLimCadreLeg[1], xLimCadreLeg[1],yLimCadreLeg[1], xLimCadreLeg[1],yLimCadreLeg[2]),ncol=2, byrow=TRUE)
+        bbox_leg_joignantes <- st_sf(geometry=st_sfc(st_polygon(list(bbox_leg_joignantes))),crs=st_crs(fondMaille))
+      }
+    }
 
     par(mai=c(0,0,0,0))
     plot(st_geometry(fondMaille),xlim=xlim,ylim=ylim,border=colBorderMaille)
@@ -242,7 +258,7 @@ function(data,fondMaille,fondSousAnalyse=NULL,fondSurAnalyse=NULL,typeMaille,idD
       }
     }
 
-    suppressWarnings(plot(bbox_leg_joignantes,add=T,col="white",border="white",lwd=1))
+    if(cadreLeg) suppressWarnings(plot(bbox_leg_joignantes,add=T,col="white",border="white",lwd=1))
 
     plot(st_geometry(flux_leg),col=colFleche,border=colBorder,add=T)
     text(max(st_coordinates(flux_leg)[st_coordinates(flux_leg)[,4]==1,1])+1000,st_coordinates(flux_leg)[st_coordinates(flux_leg)[,4]==1,2][3],labels=round(vmax,precisionLegFleches),cex=0.9,adj=0)
