@@ -1,11 +1,11 @@
 plot_typo_symboles <-
-  function(fondPoints,listFonds,emprise="FRM",types=NULL,couleurs=NULL,tailles=NULL,epaisseurs=NULL,titreLeg="",xLeg=NULL,yLeg=NULL,titreCarte="",sourceCarte="",etiquettes=NULL,labels=NULL,xlim=NULL,ylim=NULL)
+  function(fondPoints,listFonds,emprise="FRM",types=NULL,couleurs=NULL,tailles=NULL,epaisseurs=NULL,titreLeg="",xLeg=NULL,yLeg=NULL,cadreLeg=FALSE,xLimCadreLeg=NULL,yLimCadreLeg=NULL,titreCarte="",sourceCarte="",etiquettes=NULL,labels=NULL,xlim=NULL,ylim=NULL)
   {
     options("stringsAsFactors"=FALSE)
 
     # Verification des parametres
 
-    msg_error1<-msg_error2<-msg_error3<-msg_error4<-msg_error5<-msg_error6<-msg_error7<-msg_error8<-msg_error9<-msg_error10<-msg_error11<-msg_error12<-msg_error13<-msg_error14<-msg_error15<-msg_error16<-msg_error17 <- NULL
+    msg_error1<-msg_error2<-msg_error3<-msg_error4<-msg_error5<-msg_error6<-msg_error7<-msg_error8<-msg_error9<-msg_error10<-msg_error11<-msg_error12<-msg_error13<-msg_error14<-msg_error15<-msg_error16<-msg_error17<-msg_error18<-msg_error19<-msg_error20 <- NULL
 
     if(any(!any(class(fondPoints) %in% "sf"),!any(class(fondPoints) %in% "data.frame"))) msg_error1 <- "Le fond de points doit etre un objet sf / "
     if(any(!any(class(listFonds[[1]]) %in% "sf"),!any(class(listFonds[[1]]) %in% "data.frame"))) msg_error2 <- "La liste des fonds doit etre une liste d'objets sf / "
@@ -17,27 +17,49 @@ plot_typo_symboles <-
     if(any(class(titreLeg)!="character")) msg_error8 <- "Le titre de la legende doit etre de type caractere / "
     if(!is.null(xLeg)) if(any(class(xLeg)!="numeric")) msg_error9 <- "La variable xLeg doit etre de type numerique / "
     if(!is.null(yLeg)) if(any(class(yLeg)!="numeric")) msg_error10 <- "La variable yLeg doit etre de type numerique / "
-    if(any(class(titreCarte)!="character")) msg_error11 <- "Le titre de la carte doit etre de type caractere / "
-    if(any(class(sourceCarte)!="character")) msg_error12 <- "La source de la carte doit etre de type caractere / "
-    if(!is.null(etiquettes)) if(!any(class(etiquettes) %in% "character" | class(etiquettes) %in% "data.frame")) msg_error13 <- "La table des etiquettes peut etre soit un vecteur caractere soit un data.frame (voir aide) / "
-    if(!emprise %in% c("FRM","971","972","973","974","976")) msg_error14 <- "La variable emprise doit etre 'FRM', '971', '972', '973', '974' ou '976' / "
-    if(!is.null(labels)) if(any(class(labels)!="character")) msg_error15 <- "Les labels doivent etre un vecteur de type caractere / "
-    if(!is.null(xlim)) if(any(class(xlim)!="numeric")) msg_error16 <- "La variable xlim doit etre de type numerique / "
-    if(!is.null(ylim)) if(any(class(ylim)!="numeric")) msg_error17 <- "La variable yim doit etre de type numerique / "
+    if(any(class(cadreLeg)!="logical")) msg_error11 <- "La variable cadreLeg doit etre logique TRUE ou FALSE / "
+    if(!is.null(xLimCadreLeg)) if(any(class(xLimCadreLeg)!="numeric")) msg_error12 <- "La variable xLimCadreLeg doit etre de type numerique / "
+    if(!is.null(yLimCadreLeg)) if(any(class(yLimCadreLeg)!="numeric")) msg_error13 <- "La variable yLimCadreLeg doit etre de type numerique / "
+    if(any(class(titreCarte)!="character")) msg_error14 <- "Le titre de la carte doit etre de type caractere / "
+    if(any(class(sourceCarte)!="character")) msg_error15 <- "La source de la carte doit etre de type caractere / "
+    if(!is.null(etiquettes)) if(!any(class(etiquettes) %in% "character" | class(etiquettes) %in% "data.frame")) msg_error16 <- "La table des etiquettes peut etre soit un vecteur caractere soit un data.frame (voir aide) / "
+    if(!emprise %in% c("FRM","971","972","973","974","976")) msg_error17 <- "La variable emprise doit etre 'FRM', '971', '972', '973', '974' ou '976' / "
+    if(!is.null(labels)) if(any(class(labels)!="character")) msg_error18 <- "Les labels doivent etre un vecteur de type caractere / "
+    if(!is.null(xlim)) if(any(class(xlim)!="numeric")) msg_error19 <- "La variable xlim doit etre de type numerique / "
+    if(!is.null(ylim)) if(any(class(ylim)!="numeric")) msg_error20 <- "La variable yim doit etre de type numerique / "
 
     if(any(!is.null(msg_error1),!is.null(msg_error2),!is.null(msg_error3),!is.null(msg_error4),
            !is.null(msg_error5),!is.null(msg_error6),!is.null(msg_error7),!is.null(msg_error8),
            !is.null(msg_error9),!is.null(msg_error10),!is.null(msg_error11),!is.null(msg_error12),
-           !is.null(msg_error13),!is.null(msg_error14),!is.null(msg_error15),!is.null(msg_error16),!is.null(msg_error17)))
+           !is.null(msg_error13),!is.null(msg_error14),!is.null(msg_error15),!is.null(msg_error16),
+           !is.null(msg_error17),!is.null(msg_error18),!is.null(msg_error19),!is.null(msg_error20)))
     {
       stop(simpleError(paste0(msg_error1,msg_error2,msg_error3,msg_error4,msg_error5,msg_error6,msg_error7,msg_error8,
-                              msg_error9,msg_error10,msg_error11,msg_error12,msg_error13,msg_error14,msg_error15,msg_error16,msg_error17)))
+                              msg_error9,msg_error10,msg_error11,msg_error12,msg_error13,msg_error14,msg_error15,msg_error16,
+                              msg_error17,msg_error18,msg_error19,msg_error20)))
     }
 
     names(fondPoints)[1] <- "CODE"
     names(fondPoints)[2] <- "LIBELLE"
     fondPoints$LIBELLE<-iconv(fondPoints$LIBELLE,"latin1","utf8")
 
+    if(titreLeg!="")
+    {
+      titreLeg<-iconv(titreLeg,"latin1","utf8")
+    }
+    if(titreCarte!="")
+    {
+      titreCarte<-iconv(titreCarte,"latin1","utf8")
+    }
+    if(sourceCarte!="")
+    {
+      sourceCarte<-iconv(sourceCarte,"latin1","utf8")
+    }
+    if(!is.null(labels))
+    {
+      labels<-iconv(labels,"latin1","utf8")
+    }
+
     code_epsg <- switch(emprise, #emprise
                         "FRM"="2154",# Lambert 93
                         "971"="5490",# UTM 20 N
@@ -107,8 +129,19 @@ plot_typo_symboles <-
     xmax <- max(sf::st_coordinates(fondPointsLeg)[,1]) + (x_large*5)
     ymin <- min(sf::st_coordinates(fondPointsLeg)[,2]) - (y_large*2)
     ymax <- max(sf::st_coordinates(fondPointsLeg)[,2]) + (y_large*3)
-    bbox_leg_typo_symboles <- matrix(c(xmin,ymax, xmax,ymax, xmax,ymin, xmin,ymin, xmin,ymax),ncol=2, byrow=TRUE)
-    bbox_leg_typo_symboles <- sf::st_sf(geometry=sf::st_sfc(sf::st_polygon(list(bbox_leg_typo_symboles))),crs=sf::st_crs(fondPoints))
+
+    if(cadreLeg)
+    {
+      if(is.null(xLimCadreLeg) | is.null(xLimCadreLeg))
+      {
+        bbox_leg_typo_symboles <- matrix(c(xmin,ymax, xmax,ymax, xmax,ymin, xmin,ymin, xmin,ymax),ncol=2, byrow=TRUE)
+        bbox_leg_typo_symboles <- st_sf(geometry=st_sfc(st_polygon(list(bbox_leg_typo_symboles))),crs=st_crs(fondPoints))
+      }else
+      {
+        bbox_leg_typo_symboles <- matrix(c(xLimCadreLeg[1],yLimCadreLeg[2], xLimCadreLeg[2],yLimCadreLeg[2], xLimCadreLeg[2],yLimCadreLeg[1], xLimCadreLeg[1],yLimCadreLeg[1], xLimCadreLeg[1],yLimCadreLeg[2]),ncol=2, byrow=TRUE)
+        bbox_leg_typo_symboles <- st_sf(geometry=st_sfc(st_polygon(list(bbox_leg_typo_symboles))),crs=st_crs(fondPoints))
+      }
+    }
 
     if(!is.null(etiquettes))
     {
@@ -146,7 +179,7 @@ plot_typo_symboles <-
       }
     }
 
-    # suppressWarnings(plot(bbox_leg_typo_symboles,add=T,col="white",border="white",lwd=1))
+    if(cadreLeg) suppressWarnings(plot(bbox_leg_typo_symboles,add=T,col="white",border="white",lwd=1))
 
     for(i in 1:nrow(symbLeg))
     {
